package agent

import (
	"context"
	"errors"
	"fmt"
	"wechat-api/hook/fastgpt"

	"wechat-api/internal/svc"
	"wechat-api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetAgentDataListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetAgentDataListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetAgentDataListLogic {
	return &GetAgentDataListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx}
}

func (l *GetAgentDataListLogic) GetAgentDataList(req *types.DataListReq) (*types.DataListResp, error) {
	var params fastgpt.GetDataListReq
	params.CollectionId = *req.CollectionId
	params.PageSize = *req.PageSize
	params.PageNum = *req.PageNum
	resp, err := fastgpt.GetDataList(&params)
	if err != nil {
		fmt.Printf("%v", err.Error())
	}
	dataResp := types.DataListResp{}
	if resp.Code == 0 {
		for _, val := range resp.Data.Data {
			dataResp.Data = append(dataResp.Data, types.DataInfo{
				ID:           &val.ID,
				Q:            &val.Q,
				A:            &val.A,
				ChunkIndex:   &val.ChunkIndex,
				DatasetId:    &val.DatasetID,
				CollectionId: &val.CollectionID,
			})
		}

		return &dataResp, nil
	}

	return nil, errors.New(resp.Message)
}
